summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ANNOUNCE3
-rw-r--r--CHANGES7
-rw-r--r--INSTALL12
-rw-r--r--KNOWNBUG63
-rw-r--r--LICENSE11
-rw-r--r--README10
-rw-r--r--Y2KINFO4
-rwxr-xr-xconfigure2
-rw-r--r--libpng.320
-rw-r--r--libpng.txt6
-rw-r--r--libpngpf.34
-rw-r--r--msvc/README.txt2
-rw-r--r--msvc/png32ms.def2
-rw-r--r--png.52
-rw-r--r--png.c12
-rw-r--r--png.h25
-rw-r--r--pngasmrd.h2
-rw-r--r--pngconf.h2
-rw-r--r--pngerror.c2
-rw-r--r--pnggccrd.c2
-rw-r--r--pngget.c2
-rw-r--r--pngmem.c2
-rw-r--r--pngpread.c2
-rw-r--r--pngread.c6
-rw-r--r--pngrio.c2
-rw-r--r--pngrtran.c2
-rw-r--r--pngrutil.c2
-rw-r--r--pngset.c2
-rw-r--r--pngtest.c4
-rw-r--r--pngtrans.c2
-rw-r--r--pngvcrd.c2
-rw-r--r--pngwio.c2
-rw-r--r--pngwrite.c3
-rw-r--r--pngwtran.c2
-rw-r--r--pngwutil.c2
-rw-r--r--scripts/makefile.beos2
-rw-r--r--scripts/makefile.dec2
-rw-r--r--scripts/makefile.gcmmx2
-rw-r--r--scripts/makefile.hpux36
-rw-r--r--scripts/makefile.linux2
-rw-r--r--scripts/makefile.sco2
-rw-r--r--scripts/makefile.sggcc4
-rw-r--r--scripts/makefile.solaris2
-rw-r--r--scripts/pngdef.pas2
44 files changed, 135 insertions, 149 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index f8fe29792..34b5b39be 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.0.8rc1 - July 17, 2000
+Libpng 1.0.8 - July 24, 2000
This is a public release of libpng, intended for use in production codes.
@@ -19,6 +19,7 @@ Changes since the last public release (1.0.7):
Added cygwin subdirectory, makefile.cygwin, and cygwin support in pngconf.h
Added PNG_NO_ZALLOC_ZERO macro (makes png_zalloc skip zeroing memory)
Revised png_debug() macros and statements to eliminate compiler warnings.
+ Updated makefile.hpux to build a shared library.
Send comments/corrections/commendations to
png-implement@ccrc.wustl.edu or to randeg@alum.rpi.edu
diff --git a/CHANGES b/CHANGES
index 307dc38f5..1e44344b0 100644
--- a/CHANGES
+++ b/CHANGES
@@ -797,7 +797,7 @@ version 1.0.7rc2 [June 28, 2000]
Fixed "DJBPP" typo in pnggccrd.c introduced in beta18.
version 1.0.7 [July 1, 2000]
Revised the definition of "trans_values" in libpng.3/libpng.txt
-version 1.0.8rc1 [July 17, 2000]
+version 1.0.8 [July 24, 2000]
version 1.0.8beta1 [July 8, 2000]
Added png_free(png_ptr, key) two places in pngpread.c to stop memory leaks.
Changed PNG_NO_STDIO to PNG_NO_CONSOLE_IO, several places in pngrutil.c and
@@ -818,8 +818,11 @@ version 1.0.8beta4 [July 14, 2000]
Added the files pngbar.png and pngbar.jpg to the distribution.
Added cygwin subdirectory, makefile.cygwin, and cygwin support in pngconf.h
Added PNG_NO_ZALLOC_ZERO macro (makes png_zalloc skip zeroing memory)
-version 1.0.8rc1 [July 17, 2000]
+version 1.0.8rc1 [July 16, 2000]
Revised png_debug() macros and statements to eliminate compiler warnings.
+version 1.0.8 [July 24, 2000]
+ Added png_flush() in pngwrite.c, after png_write_IEND().
+ Updated makefile.hpux to build a shared library.
Send comments/corrections/commendations to
png-implement@ccrc.wustl.edu or to randeg@alum.rpi.edu
diff --git a/INSTALL b/INSTALL
index b382e8d2a..869d8108f 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
-Installing libpng version 1.0.8rc1 - July 17, 2000
+Installing libpng version 1.0.8 - July 24, 2000
Before installing libpng, you must first install zlib. zlib
can usually be found wherever you got libpng. zlib can be
@@ -10,7 +10,7 @@ zlib.h and zconf.h include files that correspond to the
version of zlib that's installed.
You can rename the directories that you downloaded (they
-might be called "libpng-1.0.8rc1" or "lpng107" and "zlib-1.1.3"
+might be called "libpng-1.0.8" or "lpng107" and "zlib-1.1.3"
or "zlib113") so that you have directories called "zlib" and "libpng".
Your directory structure should look like this:
@@ -57,8 +57,8 @@ The files that are presently available in the scripts directory
include
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
- makefile.linux => Linux/ELF makefile (gcc, creates libpng.so.2.1.0.8rc1)
- makefile.gcmmx => Linux/ELF makefile (gcc, creates libpng.so.2.1.0.8rc1,
+ makefile.linux => Linux/ELF makefile (gcc, creates libpng.so.2.1.0.8)
+ makefile.gcmmx => Linux/ELF makefile (gcc, creates libpng.so.2.1.0.8,
uses assembler code tuned for Intel MMX platform)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
@@ -70,9 +70,9 @@ include
makefile.intel => Intel C/C++ version 4.0 and later
libpng.icc => Project file for IBM VisualAge/C++ version 4.0 or later
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
- makefile.sggcc => Silicon Graphics (gcc, creates libpng.so.2.1.0.8rc1)
+ makefile.sggcc => Silicon Graphics (gcc, creates libpng.so.2.1.0.8)
makefile.sunos => Sun makefile
- makefile.solaris => Solaris 2.X makefile (gcc, creates libpng.so.2.1.0.8rc1)
+ makefile.solaris => Solaris 2.X makefile (gcc, creates libpng.so.2.1.0.8)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.mips => MIPS makefile
makefile.acorn => Acorn makefile
diff --git a/KNOWNBUG b/KNOWNBUG
index 958c7c070..013c06efa 100644
--- a/KNOWNBUG
+++ b/KNOWNBUG
@@ -1,62 +1,15 @@
-Known bugs and suggested enhancements in libpng-1.0.7
+Known bugs and suggested enhancements in libpng-1.0.8
1. July 2, 2000 -- BUG -- pnggccrd.c
- Some programs compiled with PNG_USE_PNGGCCRD crash in pnggccrd.c.
- Also, pnggccrd.c will not compile under gcc-2.95-2.
-
- STATUS: Under investigation. Experts on MMX assembler code are
- invited to help with the debugging. Note that pngvcrd.c works fine.
-
- Update: fixed in libpng-1.0.8beta1. It compiles under gcc-2.7.2.3
- and seems to work; under gcc-2.7.2.1 it compiles but crashes in
- execution. It is recommended that people use 2.95.2 or later.
-
The png_read_filter() function has still not been fully converted and
will not compile under gcc-2.95.2; it is currently ifdef'ed out.
-2. July 3, 2000 -- BUG -- MEMORY LEAK
-
- There is a memory leak in pngpread.c; it doesn't free "key".
-
- STATUS: Fixed in libpng-1.0.8beta1, by adding.
-
- png_free(png_ptr, text_ptr);
-
- after lines 1221 and 1038 in pngpread.c
-
-3. July 3, 2000 -- BUG -- PNG_EXPORT_VAR
-
- The definition of PNG_EXPORT_VAR, in pngconf.h, should be
- # define PNG_EXPORT_VAR(type) extern PNG_IMPEXP type
-
- STATUS: Fixed in libpng-1.0.8beta1.
-
-4. July 3, 2000 -- BUG -- PNG_NO_STDIO
-
- Several places in pngrutil.c and pngwutil.c, there are printf statements
- inside PNG_NO_STDIO blocks (should be PNG_NO_CONSOLE_IO)
-
- STATUS: Fixed in libpng-1.0.8beta1.
-
-5. July 3, 2000 -- ENHANCEMENT -- WindowsCE support
-
- Libpng-1.0.7 does not support WindowsCE.
-
- STATUS: Libpng-1.0.8 and libpng-2.0.0 will support WindowsCE. A
- new typedef, png_FILE_p, will be added which is normally FILE * but
- will be HANDLE if libpng is being built for WindowsCE. Other patches
- required for WindowsCE support have been provided and will be applied.
- Finished in libpng-1.0.8beta3.
-
-6. July 13, 2000 -- ENHANCEMENT -- Cygwin support
-
- Libpng-1.0.7 does not support building DLLs under Cygwin
-
- STATUS: Cygwin support has been added to libpng-1.0.8beta4.
+ STATUS: Under investigation. Experts on MMX assembler code are
+ invited to help with the debugging. Note that pngvcrd.c works fine.
-7. March 15, 1998 -- OPTIMIZATION -- Kevin Bracey
+2. March 15, 1998 -- OPTIMIZATION -- Kevin Bracey
Loops need to be optimized everywhere
@@ -68,10 +21,10 @@ Known bugs and suggested enhancements in libpng-1.0.7
Question whether i-- or --i is better.
STATUS: Under investigation, postponed until after
- libpng-1.1.0. About 160 loops will be turned around
+ libpng-2.0.0. About 160 loops will be turned around
in libpng-2.0.x betaxx, for testing.
-8. July 4, 1998 -- ENHANCEMENT -- Glenn R-P
+3. July 4, 1998 -- ENHANCEMENT -- Glenn R-P
libpng-1.0.5 and earlier transform colors to gamma=1.0 space for
merging with background, and then back to the image's gamma. The
@@ -83,12 +36,12 @@ Known bugs and suggested enhancements in libpng-1.0.7
STATUS: under development.
-9. September 1999 -- ENHANCEMENT --
+4. September 1999 -- ENHANCEMENT --
It should be possible to use libpng without floating-point aritmetic.
STATUS: Under investigation, implementation postponed until after
- libpng-1.0.7.
+ libpng-2.0.0.
Much of this was completed in libpng-1.0.6, but gamma compensation
is not yet done in fixed-point arithmetic.
diff --git a/LICENSE b/LICENSE
index 573b80a8f..24667b609 100644
--- a/LICENSE
+++ b/LICENSE
@@ -4,8 +4,9 @@ COPYRIGHT NOTICE, DISCLAIMER, and LICENSE:
If you modify libpng you may insert additional notices immediately following
this sentence.
-libpng version 1.0.8rc1, July 17, 2000 is Copyright (c) 2000 Glenn Randers-Pehrson
-Distributed according to the same disclaimer and license as libpng-1.0.6
+libpng versions 1.0.7, July 1, 2000, through 1.0.8, July 24, 2000, are
+Copyright (c) 2000 Glenn Randers-Pehrson
+and are distributed according to the same disclaimer and license as libpng-1.0.6
with the following individuals added to the list of Contributing Authors
Simon-Pierre Cadieux
@@ -22,8 +23,8 @@ and with the following additions to the disclaimer:
the user.
libpng versions 0.97, January 1998, through 1.0.6, March 20, 2000, are
-Copyright (c) 1998, 1999 Glenn Randers-Pehrson
-Distributed according to the same disclaimer and license as libpng-0.96,
+Copyright (c) 1998, 1999 Glenn Randers-Pehrson, and are
+distributed according to the same disclaimer and license as libpng-0.96,
with the following individuals added to the list of Contributing Authors:
Tom Lane
@@ -94,4 +95,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
randeg@alum.rpi.edu
-July 17, 2000
+July 24, 2000
diff --git a/README b/README
index dc75e15a2..93ac13ef1 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng 1.0.8rc1 - July 17, 2000 (shared library 2.1)
+README for libpng 1.0.8 - July 24, 2000 (shared library 2.1)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
@@ -177,9 +177,9 @@ Files in this distribution:
descrip.mms => VMS makefile for MMS or MMK
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng.so.2.1.0.8rc1)
+ (gcc, creates libpng.so.2.1.0.8)
makefile.gcmmx => Linux/ELF makefile (gcc, creates
- libpng.so.2.1.0.8rc1, uses assembler code
+ libpng.so.2.1.0.8, uses assembler code
tuned for Intel MMX platform)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
@@ -191,10 +191,10 @@ Files in this distribution:
makefile.intel => Intel C/C++ version 4.0 and later
libpng.icc => Project file, IBM VisualAge/C++ 4.0 or later
makefile.sgi => Silicon Graphics IRIX (cc, creates static lib)
- makefile.sggcc => Silicon Graphics (gcc, creates libpng.so.2.1.0.8rc1)
+ makefile.sggcc => Silicon Graphics (gcc, creates libpng.so.2.1.0.8)
makefile.sunos => Sun makefile
makefile.solaris => Solaris 2.X makefile
- (gcc, creates libpng.so.2.1.0.8rc1)
+ (gcc, creates libpng.so.2.1.0.8)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.mips => MIPS makefile
makefile.acorn => Acorn makefile
diff --git a/Y2KINFO b/Y2KINFO
index 8d8eb2426..241dd69a7 100644
--- a/Y2KINFO
+++ b/Y2KINFO
@@ -1,13 +1,13 @@
Y2K compliance in libpng:
=========================
- July 17, 2000
+ July 24, 2000
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
- upward through 1.0.8rc1 are Y2K compliant. It is my belief that earlier
+ upward through 1.0.8 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer
diff --git a/configure b/configure
index 7e3f233c2..85668cde7 100755
--- a/configure
+++ b/configure
@@ -1,5 +1,5 @@
echo "
- There is no \"configure\" script for Libpng-1.0.8rc1. Instead, please
+ There is no \"configure\" script for Libpng-1.0.8. Instead, please
copy the appropriate makefile for your system from the \"scripts\"
directory. Read the INSTALL file for more details.
"
diff --git a/libpng.3 b/libpng.3
index 184425f30..e5ceab433 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "July 17, 2000"
+.TH LIBPNG 3 "July 24, 2000"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.0.8rc1
+libpng \- Portable Network Graphics (PNG) Reference Library 1.0.8
.SH SYNOPSIS
\fI\fB
@@ -747,7 +747,7 @@ Following is a copy of the libpng.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng.txt - A description on how to use and modify libpng
- libpng version 1.0.8rc1 - July 17, 2000
+ libpng version 1.0.8 - July 24, 2000
Updated and distributed by Glenn Randers-Pehrson
<randeg@alum.rpi.edu>
Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
@@ -3381,13 +3381,13 @@ application:
.SH VII. Y2K Compliance in libpng
-July 17, 2000
+July 24, 2000
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.0.8rc1 are Y2K compliant. It is my belief that earlier
+upward through 1.0.8 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
@@ -3528,7 +3528,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.0.8rc1 - July 17, 2000:
+Libpng version 1.0.8 - July 24, 2000:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (randeg@alum.rpi.edu).
@@ -3541,9 +3541,9 @@ Supported by the PNG development group
If you modify libpng you may insert additional notices immediately following
this sentence.
-libpng version 1.0.8rc1, July 17, 2000 is
-Copyright (c) 2000 Glenn Randers-Pehrson
-Distributed according to the same disclaimer and license as libpng-1.0.6
+libpng versions 1.0.7, July 1, 2000, through 1.0.8, July 24, 2000, are
+Copyright (c) 2000 Glenn Randers-Pehrson, and are
+distributed according to the same disclaimer and license as libpng-1.0.6
with the following individuals added to the list of Contributing Authors
Simon-Pierre Cadieux
@@ -3632,7 +3632,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
randeg@alum.rpi.edu
-July 17, 2000
+July 24, 2000
.\" end of man page
diff --git a/libpng.txt b/libpng.txt
index 60dc20081..259a2f0f4 100644
--- a/libpng.txt
+++ b/libpng.txt
@@ -1,6 +1,6 @@
libpng.txt - A description on how to use and modify libpng
- libpng version 1.0.8rc1 - July 17, 2000
+ libpng version 1.0.8 - July 24, 2000
Updated and distributed by Glenn Randers-Pehrson
<randeg@alum.rpi.edu>
Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
@@ -2634,13 +2634,13 @@ application:
VII. Y2K Compliance in libpng
-July 17, 2000
+July 24, 2000
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.0.8rc1 are Y2K compliant. It is my belief that earlier
+upward through 1.0.8 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
diff --git a/libpngpf.3 b/libpngpf.3
index 4967bc669..e7ebbde80 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "July 17, 2000"
+.TH LIBPNGPF 3 "July 24, 2000"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.0.8rc1
+libpng \- Portable Network Graphics (PNG) Reference Library 1.0.8
(private functions)
.SH SYNOPSIS
\fB#include <png.h>\fP
diff --git a/msvc/README.txt b/msvc/README.txt
index b6404b319..11aa1508c 100644
--- a/msvc/README.txt
+++ b/msvc/README.txt
@@ -1,5 +1,5 @@
Microsoft Developer Studio Build File, Format Version 6.00 for
-libpng 1.0.8rc1 (July 17, 2000) and zlib
+libpng 1.0.8 (July 24, 2000) and zlib
Copyright (C) 2000 Simon-Pierre Cadieux
For conditions of distribution and use, see copyright notice in png.h
diff --git a/msvc/png32ms.def b/msvc/png32ms.def
index 5e94e5c64..e9f6cc6b7 100644
--- a/msvc/png32ms.def
+++ b/msvc/png32ms.def
@@ -6,7 +6,7 @@ LIBRARY
DESCRIPTION "PNG image compression library for Windows"
EXPORTS
-;Version 1.0.8rc1
+;Version 1.0.8
png_build_grayscale_palette @1
png_check_sig @2
png_chunk_error @3
diff --git a/png.5 b/png.5
index 0e5cfc2b8..9ff54b43b 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "July 17, 2000"
+.TH PNG 5 "July 24, 2000"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/pngasmrd.h b/pngasmrd.h
index 3e08d6c94..35fe3b242 100644
--- a/pngasmrd.h
+++ b/pngasmrd.h
@@ -1,6 +1,6 @@
/* pngasmrd.h - assembler version of utilities to read a PNG file
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1999, 2000 Glenn Randers-Pehrson
*
diff --git a/pngconf.h b/pngconf.h
index 0f83e282d..648615981 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,6 +1,6 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngerror.c b/pngerror.c
index cf7930812..3e4210f75 100644
--- a/pngerror.c
+++ b/pngerror.c
@@ -1,7 +1,7 @@
/* pngerror.c - stub functions for i/o and memory allocation
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pnggccrd.c b/pnggccrd.c
index 24115aa66..ea4f972b5 100644
--- a/pnggccrd.c
+++ b/pnggccrd.c
@@ -6,7 +6,7 @@
* and http://www.intel.com/drg/pentiumII/appnotes/923/923.htm
* for Intel's performance analysis of the MMX vs. non-MMX code.
*
- * libpng version 1.0.8rc1 - July 17, 2000
+ * libpng version 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* Copyright (c) 1998, Intel Corporation
diff --git a/pngget.c b/pngget.c
index ef63066f5..266dc3b17 100644
--- a/pngget.c
+++ b/pngget.c
@@ -1,7 +1,7 @@
/* pngget.c - retrieval of values from info struct
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngmem.c b/pngmem.c
index 12126bc42..22c77beed 100644
--- a/pngmem.c
+++ b/pngmem.c
@@ -1,7 +1,7 @@
/* pngmem.c - stub functions for memory allocation
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpread.c b/pngpread.c
index e621cc8b5..6dfd01803 100644
--- a/pngpread.c
+++ b/pngpread.c
@@ -1,7 +1,7 @@
/* pngpread.c - read a png file in push mode
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngread.c b/pngread.c
index ac652085a..d1cbc512d 100644
--- a/pngread.c
+++ b/pngread.c
@@ -1,7 +1,7 @@
/* pngread.c - read a PNG file
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -698,7 +698,7 @@ png_read_row(png_structp png_ptr, png_bytep row, png_bytep dsp_row)
* not called png_set_interlace_handling(), the display_row buffer will
* be ignored, so pass NULL to it.
*
- * [*] png_handle_alpha() does not exist yet, as of libpng version 1.0.8rc1
+ * [*] png_handle_alpha() does not exist yet, as of libpng version 1.0.8
*/
void PNGAPI
@@ -747,7 +747,7 @@ png_read_rows(png_structp png_ptr, png_bytepp row,
* only call this function once. If you desire to have an image for
* each pass of a interlaced image, use png_read_rows() instead.
*
- * [*] png_handle_alpha() does not exist yet, as of libpng version 1.0.8rc1
+ * [*] png_handle_alpha() does not exist yet, as of libpng version 1.0.8
*/
void PNGAPI
png_read_image(png_structp png_ptr, png_bytepp image)
diff --git a/pngrio.c b/pngrio.c
index 8e9a6b36b..b6e592254 100644
--- a/pngrio.c
+++ b/pngrio.c
@@ -1,7 +1,7 @@
/* pngrio.c - functions for data input
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngrtran.c b/pngrtran.c
index d84c6a2bc..da75f0a85 100644
--- a/pngrtran.c
+++ b/pngrtran.c
@@ -1,7 +1,7 @@
/* pngrtran.c - transforms the data in a row for PNG readers
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngrutil.c b/pngrutil.c
index 2be3c87b8..fc6242050 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -1,7 +1,7 @@
/* pngrutil.c - utilities to read a PNG file
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngset.c b/pngset.c
index eb6fb9e40..60923288d 100644
--- a/pngset.c
+++ b/pngset.c
@@ -1,7 +1,7 @@
/* pngset.c - storage of image information into info struct
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index f08bbb41e..1437ba7e5 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1,7 +1,7 @@
/* pngtest.c - a simple test program to test libpng
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -1448,4 +1448,4 @@ main(int argc, char *argv[])
}
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_0_8rc1 your_png_h_is_not_version_1_0_8rc1;
+typedef version_1_0_8 your_png_h_is_not_version_1_0_8;
diff --git a/pngtrans.c b/pngtrans.c
index 77d69b5f6..b974a66ae 100644
--- a/pngtrans.c
+++ b/pngtrans.c
@@ -1,7 +1,7 @@
/* pngtrans.c - transforms the data in a row (used by both readers and writers)
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngvcrd.c b/pngvcrd.c
index c446bf308..ed09aaea8 100644
--- a/pngvcrd.c
+++ b/pngvcrd.c
@@ -2,7 +2,7 @@
*
* For Intel x86 CPU and Microsoft Visual C++ compiler
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* Copyright (c) 1998, Intel Corporation
diff --git a/pngwio.c b/pngwio.c
index 9e61616de..c70062426 100644
--- a/pngwio.c
+++ b/pngwio.c
@@ -1,7 +1,7 @@
/* pngwio.c - functions for data output
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngwrite.c b/pngwrite.c
index 7c1150cec..167e77056 100644
--- a/pngwrite.c
+++ b/pngwrite.c
@@ -1,7 +1,7 @@
/* pngwrite.c - general routines to write a PNG file
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -375,6 +375,7 @@ png_write_end(png_structp png_ptr, png_infop info_ptr)
/* write end of PNG file */
png_write_IEND(png_ptr);
+ png_flush(png_ptr);
}
#if defined(PNG_WRITE_tIME_SUPPORTED)
diff --git a/pngwtran.c b/pngwtran.c
index 78999eafb..257ccd13c 100644
--- a/pngwtran.c
+++ b/pngwtran.c
@@ -1,7 +1,7 @@
/* pngwtran.c - transforms the data in a row for PNG writers
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngwutil.c b/pngwutil.c
index b41447407..fb702c986 100644
--- a/pngwutil.c
+++ b/pngwutil.c
@@ -1,7 +1,7 @@
/* pngwutil.c - utilities to write a PNG file
*
- * libpng 1.0.8rc1 - July 17, 2000
+ * libpng 1.0.8 - July 24, 2000
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/scripts/makefile.beos b/scripts/makefile.beos
index ef90394b3..7f39799cb 100644
--- a/scripts/makefile.beos
+++ b/scripts/makefile.beos
@@ -31,7 +31,7 @@ RANLIB=ranlib
# read libpng.txt or png.h to see why PNGMAJ is 2. You should not
# have to change it.
PNGMAJ = 2
-PNGMIN = 1.0.8rc1
+PNGMIN = 1.0.8
PNGVER = $(PNGMAJ).$(PNGMIN)
# where make install puts libpng.a, libpng.so*, and png.h
diff --git a/scripts/makefile.dec b/scripts/makefile.dec
index ce18ead84..b8552c051 100644
--- a/scripts/makefile.dec
+++ b/scripts/makefile.dec
@@ -14,7 +14,7 @@ ZLIBINC=../zlib
# read libpng.txt or png.h to see why PNGMAJ is 2. You should not
# have to change it.
PNGMAJ = 2
-PNGMIN = 1.0.8rc1
+PNGMIN = 1.0.8
PNGVER = $(PNGMAJ).$(PNGMIN)
CC=cc
diff --git a/scripts/makefile.gcmmx b/scripts/makefile.gcmmx
index e5b261cb3..877bb49c6 100644
--- a/scripts/makefile.gcmmx
+++ b/scripts/makefile.gcmmx
@@ -36,7 +36,7 @@ RANLIB=ranlib
# read libpng.txt or png.h to see why PNGMAJ is 2. You should not
# have to change it.
PNGMAJ = 2
-PNGMIN = 1.0.8rc1
+PNGMIN = 1.0.8
PNGVER = $(PNGMAJ).$(PNGMIN)
INCPATH=$(prefix)/include
diff --git a/scripts/makefile.hpux b/scripts/makefile.hpux
index 395625503..7fe55b0cd 100644
--- a/scripts/makefile.hpux
+++ b/scripts/makefile.hpux
@@ -1,7 +1,7 @@
# makefile for libpng, HPUX (10.20 and 11.00)
-# Copyright (C) 1999 Glenn Randers-Pehrson
+# Copyright (C) 1999, 2000 Glenn Randers-Pehrson
# Copyright (C) 1995 Guy Eric Schalnat, Group 42
-# contributed by Jim Rice, Hewlett Packard
+# contributed by Jim Rice and updated by Chris Schleicher, Hewlett Packard
# For conditions of distribution and use, see copyright notice in png.h
# Where the zlib library and include files are located
@@ -15,6 +15,12 @@ LDFLAGS=-L. -L$(ZLIBLIB) -lpng -lz -lm
RANLIB=ranlib
+# read libpng.txt or png.h to see why PNGMAJ is 2. You should not
+# have to change it.
+PNGMAJ = 2
+PNGMIN = 1.0.8
+PNGVER = $(PNGMAJ).$(PNGMIN)
+
# where make install puts libpng.a and png.h
prefix=/opt/libpng
@@ -22,12 +28,29 @@ OBJS = png.o pngset.o pngget.o pngrutil.o pngtrans.o pngwutil.o \
pngread.o pngrio.o pngwio.o pngwrite.o pngrtran.o \
pngwtran.o pngmem.o pngerror.o pngpread.o
-all: libpng.a pngtest
+OBJSDLL = $(OBJS:.o=.pic.o)
+
+.SUFFIXES: .c .o .pic.o
+
+.c.pic.o:
+ $(CC) -c $(CFLAGS) +z -o $@ $*.c
+
+all: libpng.a libpng.sl pngtest
libpng.a: $(OBJS)
ar rc $@ $(OBJS)
$(RANLIB) $@
+libpng.sl: libpng.sl.$(PNGMAJ)
+ ln -f -s libpng.sl.$(PNGMAJ) libpng.sl
+
+libpng.sl.$(PNGMAJ): libpng.sl.$(PNGVER)
+ ln -f -s libpng.sl.$(PNGVER) libpng.sl.$(PNGMAJ)
+
+libpng.sl.$(PNGVER): $(OBJSDLL)
+ $(LD) -b -L$(ZLIBLIB) +s +b $(ZLIBLIB) \
+ +h libpng.sl.$(PNGMAJ) -o libpng.sl.$(PNGVER) $(OBJSDLL) -lz
+
pngtest: pngtest.o libpng.a
$(CC) -o pngtest $(CCFLAGS) pngtest.o $(LDFLAGS)
@@ -41,11 +64,14 @@ install: libpng.a
cp pngconf.h $(prefix)/include
chmod 644 $(prefix)/include/png.h
chmod 644 $(prefix)/include/pngconf.h
- cp libpng.a $(prefix)/lib
+ cp libpng.a libpng.sl.$(PNGVER) $(prefix)/lib
chmod 644 $(prefix)/lib/libpng.a
+ chmod 755 $(prefix)/lib/libpng.sl.$(PNGVER)
+ (cd $(prefix)/lib; ln -f -s libpng.sl.$(PNGVER) libpng.sl.$(MNGMAJ); \
+ ln -f -s libpng.sl.$(PNGMAJ) libpng.sl)
clean:
- rm -f *.o libpng.a pngtest pngout.png
+ rm -f *.o libpng.a libpng.sl* pngtest pngout.png
DOCS = ANNOUNCE CHANGES INSTALL KNOWNBUG LICENSE README TODO Y2KINFO
writelock:
diff --git a/scripts/makefile.linux b/scripts/makefile.linux
index adf3af30d..2680e8af8 100644
--- a/scripts/makefile.linux
+++ b/scripts/makefile.linux
@@ -34,7 +34,7 @@ RANLIB=ranlib
# read libpng.txt or png.h to see why PNGMAJ is 2. You should not
# have to change it.
PNGMAJ = 2
-PNGMIN = 1.0.8rc1
+PNGMIN = 1.0.8
PNGVER = $(PNGMAJ).$(PNGMIN)
INCPATH=$(prefix)/include
diff --git a/scripts/makefile.sco b/scripts/makefile.sco
index f02012b6e..604d61488 100644
--- a/scripts/makefile.sco
+++ b/scripts/makefile.sco
@@ -25,7 +25,7 @@ RANLIB=echo
# read libpng.txt or png.h to see why PNGMAJ is 2. You should not
# have to change it.
PNGMAJ = 2
-PNGMIN = 1.0.8rc1
+PNGMIN = 1.0.8
PNGVER = $(PNGMAJ).$(PNGMIN)
INCPATH=$(prefix)/include
diff --git a/scripts/makefile.sggcc b/scripts/makefile.sggcc
index 1e0953b26..782fc7441 100644
--- a/scripts/makefile.sggcc
+++ b/scripts/makefile.sggcc
@@ -19,8 +19,8 @@ CFLAGS=-I$(ZLIBINC) -O2 $(WARNMORE) -fPIC -mabi=n32 # -g -DPNG_DEBUG=5
LDFLAGS=-L. -L$(ZLIBLIB) -lpng -lz -lm
LDSHARED=gcc -shared
-VER=1.0.8rc1
-LIBS=libpng.so.1.0.8rc1
+VER=1.0.8
+LIBS=libpng.so.1.0.8
SHAREDLIB=libpng.so
libdir=$(prefix)/lib32
diff --git a/scripts/makefile.solaris b/scripts/makefile.solaris
index d8a67662b..8209255aa 100644
--- a/scripts/makefile.solaris
+++ b/scripts/makefile.solaris
@@ -31,7 +31,7 @@ RANLIB=echo
# read libpng.txt or png.h to see why PNGMAJ is 2. You should not
# have to change it.
PNGMAJ = 2
-PNGMIN = 1.0.8rc1
+PNGMIN = 1.0.8
PNGVER = $(PNGMAJ).$(PNGMIN)
INCPATH=$(prefix)/include
diff --git a/scripts/pngdef.pas b/scripts/pngdef.pas
index a6a7df17b..19059314d 100644
--- a/scripts/pngdef.pas
+++ b/scripts/pngdef.pas
@@ -5,7 +5,7 @@ unit pngdef;
interface
const
- PNG_LIBPNG_VER_STRING = '1.0.8rc1';
+ PNG_LIBPNG_VER_STRING = '1.0.8';
PNG_LIBPNG_VER = 10008;
type
diff --git a/png.c b/png.c
index 325e1d01f..1b2531cd1 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
* libpng version 1.0.8rc1 - July 17, 2000
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -13,14 +13,14 @@
#include "png.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_0_8rc1 Your_png_h_is_not_version_1_0_8rc1;
+typedef version_1_0_8 Your_png_h_is_not_version_1_0_8;
/* Version information for C files. This had better match the version
* string defined in png.h. */
#ifdef PNG_USE_GLOBAL_ARRAYS
/* png_libpng_ver was changed to a function in version 1.0.5c */
-char png_libpng_ver[12] = "1.0.8rc1";
+char png_libpng_ver[12] = "1.0.8";
/* png_sig was changed to a function in version 1.0.5c */
/* Place to hold the signature string for a PNG file. */
@@ -625,7 +625,7 @@ png_charp PNGAPI
png_get_copyright(png_structp png_ptr)
{
if (png_ptr != NULL || png_ptr == NULL) /* silence compiler warning */
- return ((png_charp) "\n libpng version 1.0.8rc1 - July 17, 2000\n\
+ return ((png_charp) "\n libpng version 1.0.8 - July 24, 2000\n\
Copyright (c) 1998-2000 Glenn Randers-Pehrson\n\
Copyright (c) 1996, 1997 Andreas Dilger\n\
Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.\n");
@@ -643,8 +643,8 @@ png_get_libpng_ver(png_structp png_ptr)
{
/* Version of *.c files used when building libpng */
if(png_ptr != NULL) /* silence compiler warning about unused png_ptr */
- return((png_charp) "1.0.8rc1");
- return((png_charp) "1.0.8rc1");
+ return((png_charp) "1.0.8");
+ return((png_charp) "1.0.8");
}
png_charp PNGAPI
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
- * libpng version 1.0.8rc1 - July 17, 2000
+ * libpng version 1.0.8 - July 24, 2000
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/png.h b/png.h
index aeb86ef63..0d8e0dc1b 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.0.8rc1 - July 17, 2000
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.0.8rc1 - July 17, 2000: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -57,6 +57,7 @@
* 1.0.7 10007 (still compatible)
* 1.0.8beta1-4 10008 2.1.0.8beta1-4
* 1.0.8rc1 10008 2.1.0.8rc1
+ * 1.0.8 10008 2.1.0.8
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -83,9 +84,9 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng version 1.0.8rc1, July 17, 2000, is
* Copyright (c) 2000 Glenn Randers-Pehrson
* Distributed according to the same disclaimer and license as libpng-1.0.6
* with the following individuals added to the list of Contributing Authors
*
* Simon-Pierre Cadieux
@@ -188,13 +189,13 @@
* Y2K compliance in libpng:
* =========================
*
- * July 17, 2000
+ * July 24, 2000
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.0.8rc1 are Y2K compliant. It is my belief that earlier
+ * upward through 1.0.8 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -250,7 +251,7 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.0.8rc1"
+#define PNG_LIBPNG_VER_STRING "1.0.8"
#define PNG_LIBPNG_VER_SONUM 2
@@ -260,7 +261,7 @@
#define PNG_LIBPNG_VER_RELEASE 8
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD 1
+#define PNG_LIBPNG_VER_BUILD 0
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -1148,9 +1149,9 @@ struct png_struct_def
};
/* This prevents a compiler error in png_get_copyright() in png.c if png.c
-and png.h are both at * version 1.0.8rc1
+and png.h are both at * version 1.0.8
*/
-typedef png_structp version_1_0_8rc1;
+typedef png_structp version_1_0_8;
typedef png_struct FAR * FAR * png_structpp;
@@ -2182,7 +2183,7 @@ extern PNG_EXPORT(png_charp,png_get_header_version) PNGARG((png_structp png_ptr)
extern PNG_EXPORT(png_charp,png_get_libpng_ver) PNGARG((png_structp png_ptr));
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.0.8rc1 - July 17, 2000 (header)\n"
+ " libpng version 1.0.8 - July 24, 2000 (header)\n"
#ifdef PNG_READ_COMPOSITE_NODIV_SUPPORTED
/* With these routines we avoid an integer divide, which will be slower on
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.0.8rc1 - July 17, 2000
+ * libpng version 1.0.8 - July 24, 2000
* Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.0.8rc1 - July 17, 2000: Glenn
+ * libpng versions 0.97, January 1998, through 1.0.8 - July 24, 2000: Glenn
* See also "Contributing Authors", below.
*
@@ -83,9 +84,9 @@
* this sentence.
*
- * libpng version 1.0.8rc1, July 17, 2000, is
- * Copyright (c) 2000 Glenn Randers-Pehrson
- * Distributed according to the same disclaimer and license as libpng-1.0.6
+ * libpng versions 1.0.7, July 1, 2000, through 1.0.8, July 24, 2000, are
+ * Copyright (c) 2000 Glenn Randers-Pehrson, and are
+ * distributed according to the same disclaimer and license as libpng-1.0.6
* with the following individuals added to the list of Contributing Authors
*